OtplessTruecallerConfig class

Constructors

OtplessTruecallerConfig({OTFooterType? footerType, OTButtonShape? shape, OTVerifyOption? verifyOption, OTHeadingConsent? heading, OTLoginPrefixText? loginPrefixText, OTCtaText? ctaText, String? locale, String? buttonColor, String? buttonTextColor})
const

Properties

buttonColor → String?
final
buttonTextColor → String?
final
ctaText → OTCtaText?
final
footerType → OTFooterType?
final
hashCode → int
The hash code for this object.
no setterinherited
heading → OTHeadingConsent?
final
locale → String?
final
loginPrefixText → OTLoginPrefixText?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OTButtonShape?
final
verifyOption → OTVerifyOption?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited