Otpless class

Constructors

Otpless()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkSimBindingStatus() Future<bool>
clearSimBinding() Future<void>
closeDialogIfOpen() Future<void>
commitResponse(dynamic response) Future<void>
getActiveSession() Future<Map<String, dynamic>>
getPlatformVersion() Future<String?>
initialize(String appid, {double timeout = 30.0}) Future<void>
initSession(String appId) Future<void>
initTrueCaller(OtplessTruecallerRequest? request) Future<bool>
isSdkReady() Future<bool>
isWhatsAppInstalledForAndroid() Future<bool>
logoutSession() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendUserAuthEvent(AuthEvent event, bool fallback, ProviderType providerType, {Map<String, dynamic>? providerInfo}) Future<bool>
setDevLogging(bool isEnabled) Future<void>
setMfaEnabled(bool enabled) Future<void>
setResponseCallback(OtplessResultCallback callback) Future<void>
setSimBindingEnabled(bool enabled) Future<void>
start(OtplessResultCallback callback, Map<String, dynamic> jsonObject) Future<void>
startInBackground(OtplessResultCallback callback, Map<String, dynamic> jsonObject) Future<void>
startOnetap(OtplessResultCallback callback, OtplessAuthConfig config) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited